dm 'log;clear;output;clear';

/***************************************************************************************************
*                                           SENTINEL PROGRAM
****************************************************************************************************
* NAME:  tshpv9_ahr_wp003_nsdp_v01.sas
*
* PURPOSE: master program for TREE Extraction, a program that generates an analytic dataset for further
*          processing by TreeScan Software
*
* MAJOR STEPS: 
          - include ms_common_components.sas
*         - Include create_episodes_spans_2.sas 
*         - Include tree_extraction_SCRI.sas
* 
* KEY DEPENDENCIES/CONSTRAINTS:
*         - Common Components installation
*--------------------------------------------------------------------------------------------------
*--------------------------------------------------------------------------------------------------
* HISTORY:
*  Create date (mm/dd/yy): 02/19/15
*  Last modified date (mm/dd/yy): 05/16/16
*  Version:V1.2.0
*
*  CHANGE LOG: 
*
*   Version   Date       Comment (reference external documentation when available)
*   -------   --------   -------------------------------------------------------------------------
*     1.1     02/19/15   First production version release
*
*     1.1.1    04/15/15   Bug fixed and some additional flags added for more effective validation
*                         process    
*     1.1.2    05/14/15   %include additional code    
*     1.2.0	   05/16/16   Second production release. 
*                         Added multi_exposure feature, exposure incident criteria,
*                         ICD10 diagnoses compatability, concomitant exposure 
*
**************************************************************************************************/

/* System options */
options nosymbolgen nomlogic ;
options ls=100 nocenter ;

/*-------------------------------------------------------------------------------------------------
*                                        DEFINITIONS
*--------------------------------------------------------------------------------------------------
* MSCC     ... Mini-Sentinel Common-Components File 
*              Specific to each Data Partner/Data Site, the Common-Components defines key
*                 - macro variables (e.g. Data Partner ID, Min and Max Dates, MSCDM table names)   
*                 - libname assignments (e.g. libref INDATA is assigned to production MSCDM tables) 
*              NOTE: This parameter needs to be set by programmer at the Data Partner/Data Site
*
* MSReqID  ... Mini-Sentinel Project Request-Id
*              NOTE: This parameter needs to be set by the programmer preparing the Request-ID
*                    in coordination with the Mini-Sentinel Operations Center (MSOC)
*
* The following paths for the current request are automatically derived 
*    DPLOCAL  ... path for data created that remains local (i.e behind the DP firewall)
*    MSOC     ... path for data created to share with MS Operations Center
*    INFOLDER ... path for program inputs (e.g.lookup data, external macros)
*    SASPROGRAMS ... path for all SAS programs that are part of the data request
*-------------------------------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* NOTE: Data Partner/Data Site programmer defines parameters in this section */
/*----------------------------------------------------------------------------*/

* Enter directory and filename for common components file;

%Let MSCDMProg=;

*Example: %LET MSCDMProg=%STR($deptdata11/mscdm/mod_prg_physical_mscdm/); 

%let MSCC =  &MSCDMProg.ms_common_components.sas;

* Enter name of dataset that lists PatIDs that must be excluded from this request.
* The dataset must be in the infolder library (inputfiles folder) and must have a column named PatID;
* If no patients need to be excluded then leave parameter for ASO_EXCL_LIST blank;
%let  ASO_EXCL_LIST= ;

*Example: %let  ASO_EXCL_LIST=infolder.ASO_EXCL_LIST;

* Enter names of input files , all of them must be in the infolder library (inputfiles folder);

%let  site_info=infolder.site_info;
%let  general_input=infolder.general_input ;
%let  subgroup=infolder.subgroup ;
%let  dxtree_input=infolder.dxtree_input ;
%let  dxtree_priority=infolder.dxtree_priority ;
%let vaccine_group_enc_setting=infolder.vaccine_group_enc_setting;
%let concomitant_group=infolder.concomitant_group;
%let group_exclusion=infolder.group_exclusion; 
%let id10_id9_map=infolder.id10_id9_map;

**************************************************************************************************
*******                                  END OF USER INPUT                                  ******
*******                             DO NOT EDIT BELOW THIS LINE                             ******
*******                        (Consult with MSOC or MS team leader                         ******
*******                           if you feel edits are required)                           ******
**************************************************************************************************;

/* Include Common Components */
%inc "&MSCC" /source2 ;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing Request-Id defines the                   */
/*       parameter MSReqID in coordination with the MSOC               */
/*---------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------------------
* Specific requests are made up a project-id, workplan-type, workplan-id, unique-dpid, version-id           
*--------------------------------------------------------------------------------------------------
*
*        If this is your request   . . . . .  then set parameter values as follows 
*   ---------------------------------     -------------------------------------------------------
*   [Task Order 7 - NME Dabigatran]       %let MSProjID = to07_nme_dabi ;  
*   [WorkPlan Type]                       %let MSWPType = ahr; 
*   [Workplan # 5]                        %let MSWPID = wp005 ; 
*   [Unique DP id]                        %let MSDPID = nsdp ;     
*   [Beta 3]                              %let MSVerID = b03 ;         
*   [use underscores as delimiter]        %let dlm = _ ;                
*
*   The example values above would produce a Request-Id equal to to07_nme_dabi_ahr_wp005_nsdp_b03
*
*--------------------------------------------------------------------------------------------------*/

* Specify project-id, workplan-type, worplan-id, and version-id *;


%let MSProjID = tshpv9;
%let MSWPType = ahr;   
%let MSWPID   = wp003;   
%let MSDPID   = nsdp;   /* Note: set value to nsdp for non-specific DP type requests */ 
%let MSVerID  = v01;        
%let dlm = _ ; 

* Request-Id *. 
 * MSReqID is expected by standard MSOC code below.;

%let MSReqID = &MSProjID.&dlm.&MSWPType.&dlm.&MSWPID.&dlm.&MSDPID.&dlm.&MSVerID ;

* Delete macro variable used as delimiter as we no longer need it *;
%symdel dlm ; 

%LET prg_name_sh1=tree_extraction_SCRI;

*-ReqID is------------------------------------------------------------------------------------------------
* 0- Setup Environment
*-MSReqID ------------------------------------------------------------------------------------------------;

/*---------------------------------------------------------------------*/
/* NOTE: This is standard MSOC environment setup code -- Do Not Edit   */
/*---------------------------------------------------------------------*/

/* System options */
options obs=MAX ;
options msglevel=i ;
options mprint mprintnest ;
options errorcheck=strict errors=0 ;
options merror serror ;
options dkricond=error dkrocond=error mergenoby=warn;
options dsoptions=nonote2err noquotelenmax ;
options reuse=no ;
options fullstimer ;


/*------------------------------------------------------------------------------------------------
* NOTES:
*   For reasons of compatibility and standardization, paths must meet the following criteria:
*     1- Starting with the workplan subdirectory, all subdirectory names must be specified in
*        lower case (for UNIX compatibility)
*     2- Slashes must be forward-leaning slashes '/' (for UNIX compatibility)
*     3- Paths must end with a final forward-leaning slash '/' (extra slashes are fine)
*------------------------------------------------------------------------------------------------*/

/* Request-Id/Workplan parameter value must be lower case */
%let MSReqID = %lowcase(&MSReqID) ;

/* Define Workplan Specific Subdirectories */
%let DPLOCAL = &_root_dplocal.&MSReqID./dplocal/ ; 
%let MSOC = &_root_msoc.&MSReqID./msoc/ ;            
%let INFOLDER = &_root_inputfiles.&MSReqID./inputfiles/ ;  
%let SASPROGRAMS = &_root_sasprograms.&MSReqID./sasprograms/ ;
 
/*For Production*/
%let SASMACR=&INFOLDER.macros/;

/* Clean up paths (e.g. convert slashes and add slashes when necessary) and validate that paths exist */
%let DPLOCAL = %ms_clean_path(&DPLOCAL) ;
%let MSOC = %ms_clean_path(&MSOC) ;
%let INFOLDER = %ms_clean_path(&INFOLDER) ;
%let SASPROGRAMS = %ms_clean_path(&SASPROGRAMS) ;
%let SASMACR = %ms_clean_path(&SASMACR) ;

/* Assign libnames */
/* %ms_lib(libref-name, path-name, options=%str(options-name=options-value)) */
%ms_lib(dplocal, &DPLOCAL) 
%ms_lib(msoc, &MSOC) 
%ms_lib(infolder, &INFOLDER, options=%str(access=readonly));


**************************************************************************************************
*******                                  BEGIN PROGRAM                                     *******
**************************************************************************************************;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing Workplan Request-ID includes/writes      */
/*       the rest of the program below                                 */
/*---------------------------------------------------------------------*/


*--------------------------------------------------------------------------------------------------
* 1- Update PCOD in QA results library
*--------------------------------------------------------------------------------------------------;


* Set up list file*;
filename runlst "&dplocal.&prg_name_sh1..lst";
proc printto PRINT=runlst new;
run ;
* Set up log file*;
filename runlog "&msoc.&prg_name_sh1..log";
proc printto log=runlog new;
run ;


* Include and call macro  *;
%include "&sasmacr.create_episodes_spans_2.sas" /nosource2 ;
%include "&sasmacr.isdata.sas"/nosource2;
%include "&sasmacr.ms_delpatients.sas"/nosource2;
%include "&sasmacr.ms_time_signature.sas"/nosource2;
*--------------------------------------------------------------------------------------------------
* 2- Test common-components parameters
*--------------------------------------------------------------------------------------------------;

%include "&sasmacr.&prg_name_sh1..sas" /source2 ;



proc printto log=log; run;

proc printto print=print; run;
